@@ -16,7 +16,7 @@ use Rose::DB::Object::Metadata::Util qw(perl_hashref);
 use Rose::Object;
 our @ISA = qw(Rose::Object);
 
-our $VERSION = '0.73';
+our $VERSION = '0.74';
 
 use Rose::Object::MakeMethods::Generic
 (
@@ -144,7 +144,7 @@ sub base_classes
   return wantarray ? @$bc : $bc;
 }
 
-*base_class = \&base_classes;
+sub base_class { shift->base_classes(@_) }
 
 use constant DEFAULT_MANAGER_BASE_CLASS => 'Rose::DB::Object::Manager';
 
@@ -191,7 +191,7 @@ sub manager_base_classes
                      $self->{'manager_base_classes'}
 }
 
-*manager_base_class = \&manager_base_classes;
+sub manager_base_class { shift->manager_base_classes(@_) }
 
 sub convention_manager
 {
@@ -232,12 +232,15 @@ sub class_prefix
 
   my $class_prefix = shift;
 
-  unless($class_prefix =~ /^(?:\w+::)*\w+(?:::)?$/)
+  if(length $class_prefix)
   {
-    croak "Illegal class prefix: $class_prefix";
-  }
+    unless($class_prefix =~ /^(?:\w+::)*\w+(?:::)?$/)
+    {
+      croak "Illegal class prefix: $class_prefix";
+    }
 
-  $class_prefix .= '::'  unless($class_prefix =~ /::$/);
+    $class_prefix .= '::'  unless($class_prefix =~ /::$/);
+  }
 
   return $self->{'class_prefix'} = $class_prefix;
 }
@@ -280,8 +283,8 @@ sub db_dsn
   return $self->{'db_dsn'} = $db_dsn;
 }
 
-*dsn     = \&db_dsn;
-*dbi_dsn = \&db_dsn;
+sub dsn     { shift->db_dsn(@_) }
+sub dbi_dsn { shift->db_dsn(@_) }
 
 sub db_class
 {
@@ -534,12 +537,15 @@ sub make_classes
   my $class_prefix =  exists $args{'class_prefix'} ? 
     delete $args{'class_prefix'} : $self->class_prefix || '';
 
-  unless($class_prefix =~ /^(?:\w+::)*\w+(?:::)?$/)
+  if(length $class_prefix)
   {
-    croak "Illegal class prefix: $class_prefix";
-  }
+    unless($class_prefix =~ /^(?:\w+::)*\w+(?:::)?$/)
+    {
+      croak "Illegal class prefix: $class_prefix";
+    }
 
-  $class_prefix .= '::'  unless($class_prefix =~ /::$/);
+    $class_prefix .= '::'  unless($class_prefix =~ /::$/);
+  }
 
   # Evil masking of object attribute
   local $self->{'class_prefix'} = $class_prefix; 
@@ -1032,7 +1038,7 @@ This is an alias for the L<base_classes|/base_classes> method.
 
 =item B<base_classes [ CLASS | ARRAYREF ]>
 
-Get or set the list of base classes to use for the L<Rose::DB::Object> subclasses created by the L<make_classes|/make_classes> method.  The argument may be a class name or a reference to an array of class names.  At least one of the classes must inherit from L<Rose::DB::Object>.
+Get or set the list of base classes to use for the L<Rose::DB::Object> subclasses created by the L<make_classes|/make_classes> method.  The argument may be a class name or a reference to an array of class names.  At least one of the classes should inherit from L<Rose::DB::Object>.
 
 Returns a list (in list context) or reference to an array (in scalar context) of base class names.  Defaults to a dynamically-generated L<Rose::DB::Object> subclass name.
 
@@ -1220,6 +1226,16 @@ A boolean value or a reference to an array of relationship L<type|Rose::DB::Obje
 
 If true, the L<make_classes|/make_classes> method will set up unique key metadata for each L<Rose::DB::Object>-derived class it creates.  Defaults to true.
 
+=item B<manager_base_class CLASS>
+
+This is an alias for the L<manager_base_classes|/manager_base_classes> method.
+
+=item B<manager_base_classes [ CLASS | ARRAYREF ]>
+
+Get or set the list of base classes to use for the L<Rose::DB::Object::Manager> subclasses created by the L<make_classes|/make_classes> method.  The argument may be a class name or a reference to an array of class names.  At least one of the classes should inherit from L<Rose::DB::Object::Manager>.
+
+Returns a list (in list context) or reference to an array (in scalar context) of base class names.  Defaults to L<Rose::DB::Object::Manager>.
+
 =back
 
 =head1 AUTHOR
